# SurfAI

## 开发进度

### Phase 1: MVP (进行中)

- [x] 项目结构搭建
- [x] 配置管理 (Config)
- [x] LLM 抽象层
- [x] Kimi (Moonshot) 集成
- [x] DeepSeek 集成
- [x] OpenAI 集成
- [x] LLM Router
- [x] 浏览器核心 (Browser)
- [x] CLI 命令行接口
- [x] 示例代码
- [ ] 安装测试
- [ ] 文档完善

### Phase 2: 增强 (待开始)

- [ ] Gemini 支持
- [ ] 智能表格提取
- [ ] 数据导出 (CSV/Excel)
- [ ] 反检测增强
- [ ] 错误重试机制

### Phase 3: 云端 (待开始)

- [ ] 云端浏览器托管
- [ ] 代理 IP 池
- [ ] Dashboard
